@@ -23,12 +23,19 @@ except ImportError as _e:  # pragma: no cover
 from ._qpdf import (
     AccessMode,
     Annotation,
+    AttachedFileSpec,
+    ContentStreamInlineImage,
+    ContentStreamInstruction,
+    DataDecodingError,
     ForeignObjectError,
+    NameTree,
+    ObjectHelper,
     ObjectStreamMode,
     Page,
     PasswordError,
     Pdf,
     PdfError,
+    Rectangle,
     StreamDecodeLevel,
     Token,
     TokenFilter,
@@ -62,8 +69,17 @@ from .models import (
     unparse_content_stream,
 )
 
+from . import settings
+
+# Importing these will monkeypatch classes defined in C++ and register a new
+# pdfdoc codec
 from . import _methods, codec
 
+# While _cpphelpers is intended to be called from our C++ code only, explicitly
+# importing helps introspection tools like PyInstaller figure out that the module
+# is necessary.
+from . import _cpphelpers
+
 __libqpdf_version__ = _qpdf.qpdf_version()
 
 
