@@ -38,14 +38,11 @@ from pikepdf import (
     String,
     jbig2,
 )
+from pikepdf._exceptions import DependencyError
 from pikepdf._qpdf import Buffer
 from pikepdf.models import _transcoding
 
 
-class DependencyError(Exception):
-    "A third party dependency is needed to extract images of this type."
-
-
 class UnsupportedImageTypeError(Exception):
     "This image is formatted in a way pikepdf does not supported."
 
@@ -565,7 +562,7 @@ class PdfImage(PdfImageBase):
         except (RuntimeError, PdfError) as e:
             if (
                 'read_bytes called on unfilterable stream' in str(e)
-                and not jbig2.jbig2dec_available()
+                and not jbig2.get_decoder().available()
             ):
                 raise DependencyError(
                     "jbig2dec - not installed or installed version is too old "
