@@ -9,7 +9,6 @@ def form(resources):
     yield Pdf.open(resources / 'form.pdf')
 
 
-@needs_libqpdf_v('10.3.0', reason="decimal -> integer truncation")
 def test_button(form):
     annot = Annotation(form.Root.AcroForm.Fields[1])
     assert annot.subtype == Name.Widget
@@ -24,7 +23,6 @@ def test_button(form):
     )
 
 
-@needs_libqpdf_v('10.3.0', reason="decimal -> integer truncation")
 def test_checkbox(form):
     annot = Annotation(form.Root.AcroForm.Fields[2])
     assert annot.subtype == Name.Widget
@@ -38,3 +36,10 @@ def test_checkbox(form):
         annot.get_page_content_for_appearance(Name.XYZ, 0)
         == b'q\n1 0 0 1 4.41818 3.10912 cm\n/XYZ Do\nQ\n'
     )
+
+
+def test_annot_eq(form):
+    button = Annotation(form.Root.AcroForm.Fields[1])
+    checkbox = Annotation(form.Root.AcroForm.Fields[2])
+    assert button != checkbox
+    assert button == button
