@@ -13,6 +13,7 @@ import pytest
 from conftest import needs_python_v
 from hypothesis import assume, given, note, settings
 from hypothesis import strategies as st
+from packaging.version import Version
 from PIL import Image, ImageChops, ImageCms
 from PIL import features as PIL_features
 
@@ -719,26 +720,30 @@ def test_jbig2_not_available(jbig2, monkeypatch):
     xobj, _pdf = jbig2
     pim = PdfImage(xobj)
 
-    def raise_filenotfound(*args, **kwargs):
-        raise FileNotFoundError('jbig2dec')
+    class NotFoundJBIG2Decoder(pikepdf.jbig2.JBIG2DecoderInterface):
+        def check_available(self):
+            raise DependencyError('jbig2dec') from FileNotFoundError('jbig2dec')
 
-    monkeypatch.setattr(pikepdf.jbig2, 'run', raise_filenotfound)
+        def decode_jbig2(self, jbig2: bytes, jbig2_globals: bytes) -> bytes:
+            raise FileNotFoundError('jbig2dec')
 
-    assert not pikepdf.jbig2.jbig2dec_available()
+    monkeypatch.setattr(pikepdf.jbig2, 'get_decoder', NotFoundJBIG2Decoder)
+
+    assert not pikepdf.jbig2.get_decoder().available()
 
     with pytest.raises(DependencyError):
         pim.as_pil_image()
 
 
 needs_jbig2dec = pytest.mark.skipif(
-    not pikepdf.jbig2.jbig2dec_available(), reason="jbig2dec not installed"
+    not pikepdf.jbig2.get_decoder().available(), reason="jbig2dec not installed"
 )
 
 
 @needs_jbig2dec
 def test_jbig2_extractor(jbig2):
     xobj, _pdf = jbig2
-    pikepdf.jbig2.extract_jbig2_bytes(xobj.read_raw_bytes(), b'')
+    pikepdf.jbig2.get_decoder().decode_jbig2(xobj.read_raw_bytes(), b'')
 
 
 @needs_jbig2dec
@@ -797,12 +802,15 @@ def test_jbig2_global_palette(first_image_in):
 def test_jbig2_error(first_image_in, monkeypatch):
     xobj, _pdf = first_image_in('jbig2global.pdf')
     pim = PdfImage(xobj)
-    monkeypatch.setattr(pikepdf.jbig2, 'jbig2dec_available', lambda: True)
 
-    def raise_calledprocesserror(*args, **kwargs):
-        raise subprocess.CalledProcessError(1, 'jbig2dec')
+    class BrokenJBIG2Decoder(pikepdf.jbig2.JBIG2DecoderInterface):
+        def check_available(self):
+            return
 
-    monkeypatch.setattr(pikepdf.jbig2, 'run', raise_calledprocesserror)
+        def decode_jbig2(self, jbig2: bytes, jbig2_globals: bytes) -> bytes:
+            raise subprocess.CalledProcessError(1, 'jbig2dec')
+
+    monkeypatch.setattr(pikepdf.jbig2, 'get_decoder', BrokenJBIG2Decoder)
 
     pim = PdfImage(xobj)
     with pytest.raises(PdfError, match="unfilterable stream"):
@@ -815,14 +823,11 @@ def test_jbig2_too_old(first_image_in, monkeypatch):
     xobj, _pdf = first_image_in('jbig2global.pdf')
     pim = PdfImage(xobj)
 
-    def run_version_override(subprocargs, *args, **kwargs):
-        if '--version' in subprocargs:
-            return subprocess.CompletedProcess(subprocargs, 0, 'jbig2dec 0.12\n')
-        return subprocess.run(  # pylint: disable=subprocess-run-check
-            subprocargs, *args, **kwargs
-        )
+    class OldJBIG2Decoder(pikepdf.jbig2.JBIG2Decoder):
+        def _version(self):
+            return Version('0.12')
 
-    monkeypatch.setattr(pikepdf.jbig2, 'run', run_version_override)
+    monkeypatch.setattr(pikepdf.jbig2, 'get_decoder', OldJBIG2Decoder)
 
     pim = PdfImage(xobj)
     with pytest.raises(DependencyError, match='too old'):
