@@ -18,9 +18,8 @@ from pikepdf.models.metadata import (
     XMP_NS_PDF,
     XMP_NS_XMP,
     DateConverter,
-    _fromisoformat_py36,
+    PdfMetadata,
     decode_pdf_date,
-    fromisoformat,
 )
 
 pytestmark = pytest.mark.filterwarnings('ignore:.*XMLParser.*:DeprecationWarning')
@@ -685,33 +684,11 @@ def test_xmp_metadatadate_timezone(sandwich, outpdf):
 
     with Pdf.open(outpdf) as pdf:
         with pdf.open_metadata() as m:
-            dt = fromisoformat(m['xmp:MetadataDate'])
+            dt = datetime.fromisoformat(m['xmp:MetadataDate'])
             assert dt.tzinfo is not None
             assert dt.tzinfo == machine_tz
 
 
-@given(st.datetimes())
-def test_py36_isoformat_microsecs(dt):
-    s = dt.isoformat()
-    assert _fromisoformat_py36(s) == dt
-
-
-@given(st.datetimes())
-def test_py36_isoformat_seconds(dt):
-    rounded_dt = dt.replace(microsecond=0)
-    s = rounded_dt.isoformat()
-    assert _fromisoformat_py36(s) == rounded_dt
-
-
-def test_py36_isoformat_tz_punct():
-    _fromisoformat_py36('2020-12-31T11:22:33+10:30')
-
-
-def test_py36_isoformat_invalid():
-    with pytest.raises(ValueError):
-        _fromisoformat_py36('not a datetime')
-
-
 def test_modify_not_opened(graph):
     m = graph.open_metadata()
     with pytest.raises(RuntimeError, match='not opened for editing'):
@@ -752,3 +729,7 @@ def test_xxe(trivial, outdir):
     )
     with trivial.open_metadata() as m:
         assert 'This is a secret' not in str(m)
+
+
+def test_qname_no_namespace():
+    assert PdfMetadata._qname('abc') == '{adobe:ns:meta/}abc'
