@@ -7,15 +7,18 @@ import os
 import shutil
 import sys
 import zlib
+from contextlib import nullcontext
 from io import BytesIO, StringIO
 from os import fspath
 from pathlib import Path
+from subprocess import CalledProcessError
 from unittest.mock import Mock
 
 import pytest
 
 import pikepdf
 from pikepdf import Name, PasswordError, Pdf, PdfError, Stream
+from pikepdf._exceptions import DependencyError
 
 # pylint: disable=redefined-outer-name
 
@@ -334,6 +337,22 @@ def test_check(resources):
         assert 'parse error while reading' in problems[0]
 
 
+def test_check_specialized_decoder_fallback(resources, monkeypatch):
+    class MissingJBIG2Decoder(pikepdf.jbig2.JBIG2DecoderInterface):
+        def check_available(self):
+            raise DependencyError('jbig2dec')
+
+        def decode_jbig2(self, jbig2: bytes, jbig2_globals: bytes) -> bytes:
+            raise CalledProcessError(1, 'jbig2dec')
+
+    monkeypatch.setattr(pikepdf.jbig2, 'get_decoder', MissingJBIG2Decoder)
+
+    with pikepdf.open(resources / 'jbig2.pdf') as pdf:
+        with pytest.warns(UserWarning, match=r".*missing some specialized.*"):
+            problems = pdf.check()
+        assert len(problems) == 0
+
+
 def test_repr(trivial):
     assert repr(trivial).startswith('<')
 
@@ -360,17 +379,17 @@ def test_invalid_flate_compression_level():
     # and will change subsequent test results, so just ping it with an invalid
     # value to get partial code coverage.
     with pytest.raises(ValueError):
-        pikepdf._qpdf.set_flate_compression_level(99)
+        pikepdf.settings.set_flate_compression_level(99)
 
 
 def test_flate_compression_level():
     # While this function affects global state, we can test it safely because
     # setting the value to -1 restores the default.
     try:
-        pikepdf._qpdf.set_flate_compression_level(0)
-        pikepdf._qpdf.set_flate_compression_level(9)
+        pikepdf.settings.set_flate_compression_level(0)
+        pikepdf.settings.set_flate_compression_level(9)
     finally:
-        pikepdf._qpdf.set_flate_compression_level(-1)
+        pikepdf.settings.set_flate_compression_level(-1)
 
 
 def test_set_access_default_mmap():
@@ -390,13 +409,11 @@ def test_generate_appearance_streams(pdf_form):
     assert Name.AP in pdf_form.Root.AcroForm.Fields[0]
 
 
-@pytest.mark.skipif(sys.version_info < (3, 7), reason="Python 3.6 has no nullcontext")
 @pytest.mark.parametrize(
     'mode, exc',
     [('all', None), ('print', None), ('screen', None), ('', None), ('42', ValueError)],
 )
 def test_flatten_annotations_parameters(pdf_form, mode, exc):
-    from contextlib import nullcontext
 
     if exc is not None:
         error_ctx = pytest.raises(exc)
